Struct counters_DescriptorVmo
Source #[repr(C)]
pub struct counters_DescriptorVmo {
pub magic: u64,
pub max_cpus: u64,
pub descriptor_table_size: u64,
pub descriptor_table: __IncompleteArrayField<counters_Descriptor>,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.